@@ -400,33 +400,24 @@ class _GlancesCurses(object):
 
     def disable_top(self):
         """Disable the top panel"""
-        self.args.disable_quicklook = True
-        self.args.disable_cpu = True
-        self.args.disable_mem = True
-        self.args.disable_memswap = True
-        self.args.disable_load = True
+        for p in ['quicklook', 'cpu', 'gpu', 'mem', 'memswap', 'load']:
+            setattr(self.args, 'disable_' + p, True)
 
     def enable_top(self):
         """Enable the top panel"""
-        self.args.disable_quicklook = False
-        self.args.disable_cpu = False
-        self.args.disable_mem = False
-        self.args.disable_memswap = False
-        self.args.disable_load = False
+        for p in ['quicklook', 'cpu', 'gpu', 'mem', 'memswap', 'load']:
+            setattr(self.args, 'disable_' + p, False)
 
     def disable_fullquicklook(self):
         """Disable the full quicklook mode"""
-        self.args.disable_quicklook = False
-        self.args.disable_cpu = False
-        self.args.disable_mem = False
-        self.args.disable_memswap = False
+        for p in ['quicklook', 'cpu', 'gpu', 'mem', 'memswap']:
+            setattr(self.args, 'disable_' + p, False)
 
     def enable_fullquicklook(self):
         """Disable the full quicklook mode"""
         self.args.disable_quicklook = False
-        self.args.disable_cpu = True
-        self.args.disable_mem = True
-        self.args.disable_memswap = True
+        for p in ['cpu', 'gpu', 'mem', 'memswap']:
+            setattr(self.args, 'disable_' + p, True)
 
     def end(self):
         """Shutdown the curses window."""
@@ -725,7 +716,8 @@ class _GlancesCurses(object):
         if not self.args.disable_left_sidebar:
             for s in ['network', 'wifi', 'ports', 'diskio', 'fs', 'irq',
                       'folders', 'raid', 'sensors', 'now']:
-                if hasattr(self.args, 'disable_' + s) and s in stat_display:
+                if (hasattr(self.args, 'enable_' + s) or
+                    hasattr(self.args, 'disable_' + s)) and s in stat_display:
                     self.new_line()
                     self.display_plugin(stat_display[s])
 
