@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -78,6 +78,7 @@ class Plugin(GlancesPlugin):
         """Reset/init the stats."""
         self.stats = []
 
+    @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update sensors stats using the input method."""
@@ -131,9 +132,6 @@ class Plugin(GlancesPlugin):
 
             pass
 
-        # Update the view
-        self.update_views()
-
         return self.stats
 
     def __set_type(self, stats, sensor_type):
@@ -184,7 +182,7 @@ class Plugin(GlancesPlugin):
 
         for i in self.stats:
             # Do not display anything if no battery are detected
-            if (i['type'] == 'battery' and i['value'] == []):
+            if i['type'] == 'battery' and i['value'] == []:
                 continue
             # New line
             ret.append(self.curse_new_line())
@@ -262,8 +260,8 @@ class GlancesGrabSensors(object):
                         try:
                             sensors_current['label'] = feature.label
                             sensors_current['value'] = int(feature.get_value())
-                        except SensorsError as e:
-                            logger.debug("Cannot grab sensor stat(%s)" % e)
+                        except Exception as e:
+                            logger.debug("Cannot grab sensor stat (%s)" % e)
                         else:
                             self.sensors_list.append(sensors_current)
 
