@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,10 +19,9 @@
 
 import operator
 import os
-import re
 
 from glances.compat import iteritems, itervalues, listitems
-from glances.globals import BSD, LINUX, OSX, WINDOWS
+from glances.globals import BSD, LINUX, MACOS, WINDOWS
 from glances.timer import Timer, getTimeSinceLastUpdate
 from glances.processes_tree import ProcessTreeNode
 from glances.filter import GlancesFilter
@@ -70,7 +69,7 @@ class GlancesProcesses(object):
         self._sort_key = 'cpu_percent'
         self.allprocesslist = []
         self.processlist = []
-        self.processcount = {'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
+        self.reset_processcount()
 
         # Tag to enable/disable the processes stats (to reduce the Glances CPU consumption)
         # Default is to enable the processes stats
@@ -88,6 +87,20 @@ class GlancesProcesses(object):
         # Whether or not to hide kernel threads
         self.no_kernel_threads = False
 
+        # Store maximums values in a dict
+        # Used in the UI to highlight the maximum value
+        self._max_values_list = ('cpu_percent', 'memory_percent')
+        # { 'cpu_percent': 0.0, 'memory_percent': 0.0 }
+        self._max_values = {}
+        self.reset_max_values()
+
+    def reset_processcount(self):
+        self.processcount = {'total': 0,
+                             'running': 0,
+                             'sleeping': 0,
+                             'thread': 0,
+                             'pid_max': None}
+
     def enable(self):
         """Enable process stats."""
         self.disable_tag = False
@@ -106,6 +119,37 @@ class GlancesProcesses(object):
         """Disable extended process stats."""
         self.disable_extended_tag = True
 
+    @property
+    def pid_max(self):
+        """
+        Get the maximum PID value.
+
+        On Linux, the value is read from the `/proc/sys/kernel/pid_max` file.
+
+        From `man 5 proc`:
+        The default value for this file, 32768, results in the same range of
+        PIDs as on earlier kernels. On 32-bit platfroms, 32768 is the maximum
+        value for pid_max. On 64-bit systems, pid_max can be set to any value
+        up to 2^22 (PID_MAX_LIMIT, approximately 4 million).
+
+        If the file is unreadable or not available for whatever reason,
+        returns None.
+
+        Some other OSes:
+        - On FreeBSD and macOS the maximum is 99999.
+        - On OpenBSD >= 6.0 the maximum is 99999 (was 32766).
+        - On NetBSD the maximum is 30000.
+
+        :returns: int or None
+        """
+        if LINUX:
+            # XXX: waiting for https://github.com/giampaolo/psutil/issues/720
+            try:
+                with open('/proc/sys/kernel/pid_max', 'rb') as f:
+                    return int(f.read())
+            except (OSError, IOError):
+                return None
+
     @property
     def max_processes(self):
         """Get the maximum number of processes showed in the UI."""
@@ -161,31 +205,67 @@ class GlancesProcesses(object):
 
         return True
 
+    def max_values(self):
+        """Return the max values dict."""
+        return self._max_values
+
+    def get_max_values(self, key):
+        """Get the maximum values of the given stat (key)."""
+        return self._max_values[key]
+
+    def set_max_values(self, key, value):
+        """Set the maximum value for a specific stat (key)."""
+        self._max_values[key] = value
+
+    def reset_max_values(self):
+        """Reset the maximum values dict."""
+        self._max_values = {}
+        for k in self._max_values_list:
+            self._max_values[k] = 0.0
+
     def __get_mandatory_stats(self, proc, procstat):
         """
-        Get mandatory_stats: need for the sorting/filter step.
+        Get mandatory_stats: for all processes.
+        Needed for the sorting/filter step.
 
-        => cpu_percent, memory_percent, io_counters, name, cmdline
+        Stats grabbed inside this method:
+        * 'name', 'cpu_times', 'status', 'ppid'
+        * 'username', 'cpu_percent', 'memory_percent'
         """
         procstat['mandatory_stats'] = True
 
-        # Process CPU, MEM percent and name
+        # Name, cpu_times, status and ppid stats are in the same /proc file
+        # Optimisation fir issue #958
         try:
             procstat.update(proc.as_dict(
-                attrs=['username', 'cpu_percent', 'memory_percent',
-                       'name', 'cpu_times'], ad_value=''))
+                attrs=['name', 'cpu_times', 'status', 'ppid'],
+                ad_value=''))
         except psutil.NoSuchProcess:
-            # Try/catch for issue #432
+            # Try/catch for issue #432 (process no longer exist)
             return None
+        else:
+            procstat['status'] = str(procstat['status'])[:1].upper()
+
+        try:
+            procstat.update(proc.as_dict(
+                attrs=['username', 'cpu_percent', 'memory_percent'],
+                ad_value=''))
+        except psutil.NoSuchProcess:
+            # Try/catch for issue #432 (process no longer exist)
+            return None
+
         if procstat['cpu_percent'] == '' or procstat['memory_percent'] == '':
             # Do not display process if we cannot get the basic
             # cpu_percent or memory_percent stats
             return None
 
+        # Compute the maximum value for cpu_percent and memory_percent
+        for k in self._max_values_list:
+            if procstat[k] > self.get_max_values(k):
+                self.set_max_values(k, procstat[k])
+
         # Process command line (cached with internal cache)
-        try:
-            self.cmdline_cache[procstat['pid']]
-        except KeyError:
+        if procstat['pid'] not in self.cmdline_cache:
             # Patch for issue #391
             try:
                 self.cmdline_cache[procstat['pid']] = proc.cmdline()
@@ -198,168 +278,107 @@ class GlancesProcesses(object):
         # [read_bytes, write_bytes, read_bytes_old, write_bytes_old, io_tag]
         # If io_tag = 0 > Access denied (display "?")
         # If io_tag = 1 > No access denied (display the IO rate)
-        # Note Disk IO stat not available on Mac OS
-        if not OSX:
+        # Availability: all platforms except macOS and Illumos/Solaris
+        try:
+            # Get the process IO counters
+            proc_io = proc.io_counters()
+            io_new = [proc_io.read_bytes, proc_io.write_bytes]
+        except (psutil.AccessDenied, psutil.NoSuchProcess, NotImplementedError):
+            # Access denied to process IO (no root account)
+            # NoSuchProcess (process die between first and second grab)
+            # Put 0 in all values (for sort) and io_tag = 0 (for display)
+            procstat['io_counters'] = [0, 0] + [0, 0]
+            io_tag = 0
+        except AttributeError:
+            return procstat
+        else:
+            # For IO rate computation
+            # Append saved IO r/w bytes
             try:
-                # Get the process IO counters
-                proc_io = proc.io_counters()
-                io_new = [proc_io.read_bytes, proc_io.write_bytes]
-            except (psutil.AccessDenied, psutil.NoSuchProcess, NotImplementedError):
-                # Access denied to process IO (no root account)
-                # NoSuchProcess (process die between first and second grab)
-                # Put 0 in all values (for sort) and io_tag = 0 (for
-                # display)
-                procstat['io_counters'] = [0, 0] + [0, 0]
-                io_tag = 0
-            else:
-                # For IO rate computation
-                # Append saved IO r/w bytes
-                try:
-                    procstat['io_counters'] = io_new + \
-                        self.io_old[procstat['pid']]
-                except KeyError:
-                    procstat['io_counters'] = io_new + [0, 0]
-                # then save the IO r/w bytes
-                self.io_old[procstat['pid']] = io_new
-                io_tag = 1
+                procstat['io_counters'] = io_new + self.io_old[procstat['pid']]
+            except KeyError:
+                procstat['io_counters'] = io_new + [0, 0]
+            # then save the IO r/w bytes
+            self.io_old[procstat['pid']] = io_new
+            io_tag = 1
 
-            # Append the IO tag (for display)
-            procstat['io_counters'] += [io_tag]
+        # Append the IO tag (for display)
+        procstat['io_counters'] += [io_tag]
 
         return procstat
 
     def __get_standard_stats(self, proc, procstat):
         """
-        Get standard_stats: for all the displayed processes.
+        Get standard_stats: only for displayed processes.
 
-        => username, status, memory_info, cpu_times
+        Stats grabbed inside this method:
+        * nice and memory_info
         """
         procstat['standard_stats'] = True
 
-        # Process username (cached with internal cache)
-        try:
-            self.username_cache[procstat['pid']]
-        except KeyError:
-            try:
-                self.username_cache[procstat['pid']] = proc.username()
-            except psutil.NoSuchProcess:
-                self.username_cache[procstat['pid']] = "?"
-            except (KeyError, psutil.AccessDenied):
-                try:
-                    self.username_cache[procstat['pid']] = proc.uids().real
-                except (KeyError, AttributeError, psutil.AccessDenied):
-                    self.username_cache[procstat['pid']] = "?"
-        procstat['username'] = self.username_cache[procstat['pid']]
-
-        # Process status, nice, memory_info and cpu_times
+        # Process nice and memory_info (issue #926)
         try:
             procstat.update(
-                proc.as_dict(attrs=['status', 'nice', 'memory_info', 'cpu_times']))
+                proc.as_dict(attrs=['nice', 'memory_info']))
         except psutil.NoSuchProcess:
             pass
-        else:
-            procstat['status'] = str(procstat['status'])[:1].upper()
 
         return procstat
 
     def __get_extended_stats(self, proc, procstat):
         """
-        Get extended_stats: only for top processes (see issue #403).
+        Get extended stats, only for top processes (see issue #403).
 
-        => connections (UDP/TCP), memory_swap...
+        - cpu_affinity (Linux, Windows, FreeBSD)
+        - ionice (Linux and Windows > Vista)
+        - memory_full_info (Linux)
+        - num_ctx_switches (not available on Illumos/Solaris)
+        - num_fds (Unix-like)
+        - num_handles (Windows)
+        - num_threads (not available on *BSD)
+        - memory_maps (only swap, Linux)
+          https://www.cyberciti.biz/faq/linux-which-process-is-using-swap/
+        - connections (TCP and UDP)
         """
         procstat['extended_stats'] = True
 
-        # CPU affinity (Windows and Linux only)
-        try:
-            procstat.update(proc.as_dict(attrs=['cpu_affinity']))
-        except psutil.NoSuchProcess:
-            pass
-        except AttributeError:
-            procstat['cpu_affinity'] = None
-        # Memory extended
-        try:
-            procstat.update(proc.as_dict(attrs=['memory_full_info']))
-        except psutil.NoSuchProcess:
-            pass
-        except AttributeError:
-            # Fallback to standard memory_info stats
+        for stat in ['cpu_affinity', 'ionice', 'memory_full_info',
+                     'num_ctx_switches', 'num_fds', 'num_handles',
+                     'num_threads']:
             try:
-                procstat.update(proc.as_dict(attrs=['memory_info']))
+                procstat.update(proc.as_dict(attrs=[stat]))
             except psutil.NoSuchProcess:
                 pass
-            except AttributeError:
-                procstat['memory_info'] = None
-        # Number of context switch
-        try:
-            procstat.update(proc.as_dict(attrs=['num_ctx_switches']))
-        except psutil.NoSuchProcess:
-            pass
-        except AttributeError:
-            procstat['num_ctx_switches'] = None
-        # Number of file descriptors (Unix only)
-        try:
-            procstat.update(proc.as_dict(attrs=['num_fds']))
-        except psutil.NoSuchProcess:
-            pass
-        except AttributeError:
-            procstat['num_fds'] = None
-        # Threads number
-        try:
-            procstat.update(proc.as_dict(attrs=['num_threads']))
-        except psutil.NoSuchProcess:
-            pass
-        except AttributeError:
-            procstat['num_threads'] = None
+            # XXX: psutil>=4.3.1 raises ValueError while <4.3.1 raises AttributeError
+            except (ValueError, AttributeError):
+                procstat[stat] = None
 
-        # Number of handles (Windows only)
-        if WINDOWS:
-            try:
-                procstat.update(proc.as_dict(attrs=['num_handles']))
-            except psutil.NoSuchProcess:
-                pass
-        else:
-            procstat['num_handles'] = None
-
-        # SWAP memory (Only on Linux based OS)
-        # http://www.cyberciti.biz/faq/linux-which-process-is-using-swap/
         if LINUX:
             try:
-                procstat['memory_swap'] = sum(
-                    [v.swap for v in proc.memory_maps()])
+                procstat['memory_swap'] = sum([v.swap for v in proc.memory_maps()])
             except psutil.NoSuchProcess:
                 pass
-            except psutil.AccessDenied:
-                procstat['memory_swap'] = None
-            except Exception:
-                # Add a dirty except to handle the PsUtil issue #413
+            except (psutil.AccessDenied, TypeError, NotImplementedError):
+                # NotImplementedError: /proc/${PID}/smaps file doesn't exist
+                # on kernel < 2.6.14 or CONFIG_MMU kernel configuration option
+                # is not enabled (see psutil #533/glances #413).
+                # XXX: Remove TypeError once we'll drop psutil < 3.0.0.
                 procstat['memory_swap'] = None
 
-        # Process network connections (TCP and UDP)
         try:
             procstat['tcp'] = len(proc.connections(kind="tcp"))
             procstat['udp'] = len(proc.connections(kind="udp"))
-        except Exception:
+        except psutil.AccessDenied:
             procstat['tcp'] = None
             procstat['udp'] = None
 
-        # IO Nice
-        # http://pythonhosted.org/psutil/#psutil.Process.ionice
-        if LINUX or WINDOWS:
-            try:
-                procstat.update(proc.as_dict(attrs=['ionice']))
-            except psutil.NoSuchProcess:
-                pass
-        else:
-            procstat['ionice'] = None
-
         return procstat
 
     def __get_process_stats(self, proc,
                             mandatory_stats=True,
                             standard_stats=True,
                             extended_stats=False):
-        """Get stats of running processes."""
+        """Get stats of a running processes."""
         # Process ID (always)
         procstat = proc.as_dict(attrs=['pid'])
 
@@ -378,7 +397,7 @@ class GlancesProcesses(object):
         """Update the processes stats."""
         # Reset the stats
         self.processlist = []
-        self.processcount = {'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0}
+        self.reset_processcount()
 
         # Do not process if disable tag is set
         if self.disable_tag:
@@ -387,6 +406,12 @@ class GlancesProcesses(object):
         # Get the time since last update
         time_since_update = getTimeSinceLastUpdate('process_disk')
 
+        # Reset the max dict
+        self.reset_max_values()
+
+        # Update the maximum process ID (pid) number
+        self.processcount['pid_max'] = self.pid_max
+
         # Build an internal dict with only mandatories stats (sort keys)
         processdict = {}
         excluded_processes = set()
@@ -402,12 +427,12 @@ class GlancesProcesses(object):
                                          standard_stats=self.max_processes is None)
             # Check if s is note None (issue #879)
             # ignore the 'idle' process on Windows and *BSD
-            # ignore the 'kernel_task' process on OS X
+            # ignore the 'kernel_task' process on macOS
             # waiting for upstream patch from psutil
             if (s is None or
-               BSD and s['name'] == 'idle' or
-               WINDOWS and s['name'] == 'System Idle Process' or
-               OSX and s['name'] == 'kernel_task'):
+                    BSD and s['name'] == 'idle' or
+                    WINDOWS and s['name'] == 'System Idle Process' or
+                    MACOS and s['name'] == 'kernel_task'):
                 continue
             # Continue to the next process if it has to be filtered
             if self._filter.is_filtered(s):
